# appier-report

[![release](https://img.shields.io/pypi/v/appier-report.svg)](https://pypi.org/project/appier-report/)
[![docs](https://img.shields.io/website/https/ikamedawn.github.io/appier-report/index.html.svg?label=docs&down_message=unavailable&up_message=available)](https://ikamedawn.github.io/appier-report)
[![develop](https://github.com/ikamedawn/appier-report/actions/workflows/dev.yml/badge.svg)](https://github.com/ikamedawn/appier-report/actions/workflows/dev.yml)
[![main](https://github.com/ikamedawn/appier-report/actions/workflows/release.yml/badge.svg)](https://github.com/ikamedawn/appier-report/actions/workflows/release.yml)

Report APIs wrapper

## Features

* Something
* Something else
